@@ -1,8 +1,9 @@
 import click
 
+from sym.cli.helpers.params import set_login_fields
+
 from ..helpers.options import config_option
 from ..helpers.org import infer_org_from_email
-from ..helpers.params import set_login_fields
 from .sym import sym
 
 
