@@ -1,8 +1,8 @@
 import click
+from sym.shared.cli.helpers.updater import SymUpdater
 
 from sym.cli.helpers.global_options import GlobalOptions
 
-from ..helpers.updater import SymUpdater
 from .sym import sym
 
 
